@@ -1,4 +1,3 @@
 from .citation import Citation
-from .citator import Citator, Template, cite, list_cites
+from .citator import Citator, Template, cite, list_cites, insert_links
 from .tokens import TokenType, TokenOperation, StringBuilder
-from .hyperlink import insert_links
